# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing_extensions import Literal

from ......_models import BaseModel

__all__ = ["AvatarUploadResponse"]


class AvatarUploadResponse(BaseModel):
    avatar_url: str

    message: str

    success: Literal[True]
